@@ -1,8 +1,15 @@
+"""
+The tmeasures library contain measures for neural networks internals in terms of their response to transformations
+"""
+
+
 # ORDER MATTERS IN THIS FILE
 # IMPORT BASIC STUFF FIRST
 from .transformation import TransformationSet,Transformation,IdentityTransformation,InvertibleTransformation
 from .measure import MeasureResult, StratifiedMeasureResult,Measure
-from .activations_iterator import ActivationsIterator
-from . import numpy,pytorch,visualization
+from . import pytorch,visualization
+from . import np
+
+
 
 
